@@ -38,6 +38,7 @@ static int do_comment( IOBUF out, int ctb, PKT_comment *rem );
 static int do_user_id( IOBUF out, int ctb, PKT_user_id *uid );
 static int do_public_cert( IOBUF out, int ctb, PKT_public_cert *pk );
 static int do_secret_cert( IOBUF out, int ctb, PKT_secret_cert *pk );
+static int do_symkey_enc( IOBUF out, int ctb, PKT_symkey_enc *enc );
 static int do_pubkey_enc( IOBUF out, int ctb, PKT_pubkey_enc *enc );
 static u32 calc_plaintext( PKT_plaintext *pt );
 static int do_plaintext( IOBUF out, int ctb, PKT_plaintext *pt );
@@ -67,6 +68,8 @@ build_packet( IOBUF out, PACKET *pkt )
 
     if( DBG_PACKET )
 	log_debug("build_packet() type=%d\n", pkt->pkttype );
+    if( pkt->pkttype == PKT_OLD_COMMENT )
+	pkt->pkttype = PKT_COMMENT;
     assert( pkt->pkt.generic );
     if( pkt->pkttype > 15 ) /* new format */
 	ctb = 0xc0 | (pkt->pkttype & 0x3f);
@@ -85,6 +88,9 @@ build_packet( IOBUF out, PACKET *pkt )
       case PKT_SECRET_CERT:
 	rc = do_secret_cert( out, ctb, pkt->pkt.secret_cert );
 	break;
+      case PKT_SYMKEY_ENC:
+	rc = do_symkey_enc( out, ctb, pkt->pkt.symkey_enc );
+	break;
       case PKT_PUBKEY_ENC:
 	rc = do_pubkey_enc( out, ctb, pkt->pkt.pubkey_enc );
 	break;
@@ -105,7 +111,7 @@ build_packet( IOBUF out, PACKET *pkt )
 	break;
       case PKT_RING_TRUST:
       default:
-	log_bug("invalid packet type in build_packet()");
+	log_bug("invalid packet type in build_packet()\n");
 	break;
     }
 
@@ -129,6 +135,7 @@ calc_packet_length( PACKET *pkt )
       case PKT_COMMENT:
       case PKT_PUBLIC_CERT:
       case PKT_SECRET_CERT:
+      case PKT_SYMKEY_ENC:
       case PKT_PUBKEY_ENC:
       case PKT_ENCRYPTED:
       case PKT_SIGNATURE:
@@ -178,7 +185,7 @@ do_public_cert( IOBUF out, int ctb, PKT_public_cert *pkc )
     if( pkc->version < 4 )
 	write_16(a, pkc->valid_days );
     iobuf_put(a, pkc->pubkey_algo );
-    if( pkc->pubkey_algo == PUBKEY_ALGO_ELGAMAL ) {
+    if( is_ELGAMAL(pkc->pubkey_algo) ) {
 	mpi_write(a, pkc->d.elg.p );
 	mpi_write(a, pkc->d.elg.g );
 	mpi_write(a, pkc->d.elg.y );
@@ -189,7 +196,7 @@ do_public_cert( IOBUF out, int ctb, PKT_public_cert *pkc )
 	mpi_write(a, pkc->d.dsa.g );
 	mpi_write(a, pkc->d.dsa.y );
     }
-    else if( pkc->pubkey_algo == PUBKEY_ALGO_RSA ) {
+    else if( is_RSA(pkc->pubkey_algo) ) {
 	mpi_write(a, pkc->d.rsa.n );
 	mpi_write(a, pkc->d.rsa.e );
     }
@@ -263,20 +270,20 @@ do_secret_cert( IOBUF out, int ctb, PKT_secret_cert *skc )
     if( skc->version < 4 )
 	write_16(a, skc->valid_days );
     iobuf_put(a, skc->pubkey_algo );
-    if( skc->pubkey_algo == PUBKEY_ALGO_ELGAMAL ) {
+    if( is_ELGAMAL(skc->pubkey_algo) ) {
 	mpi_write(a, skc->d.elg.p );
 	mpi_write(a, skc->d.elg.g );
 	mpi_write(a, skc->d.elg.y );
 	if( skc->is_protected ) {
 	    iobuf_put(a, 0xff );
 	    iobuf_put(a, skc->protect.algo );
-	    iobuf_put(a, skc->protect.s2k );
-	    iobuf_put(a, skc->protect.hash );
-	    if( skc->protect.s2k == 1
-		|| skc->protect.s2k == 3 )
-		iobuf_write(a, skc->protect.salt, 8 );
-	    if( skc->protect.s2k == 3 )
-		iobuf_put(a, skc->protect.count );
+	    iobuf_put(a, skc->protect.s2k.mode );
+	    iobuf_put(a, skc->protect.s2k.hash_algo );
+	    if( skc->protect.s2k.mode == 1
+		|| skc->protect.s2k.mode == 4 )
+		iobuf_write(a, skc->protect.s2k.salt, 8 );
+	    if( skc->protect.s2k.mode == 4 )
+		write_32(a, skc->protect.s2k.count );
 	    iobuf_write(a, skc->protect.iv, 8 );
 	}
 	else
@@ -285,7 +292,7 @@ do_secret_cert( IOBUF out, int ctb, PKT_secret_cert *skc )
 	mpi_write(a, skc->d.elg.x );
 	write_16(a, skc->csum );
     }
-    else if( skc->pubkey_algo == PUBKEY_ALGO_RSA ) {
+    else if( is_RSA(skc->pubkey_algo) ) {
 	mpi_write(a, skc->d.rsa.n );
 	mpi_write(a, skc->d.rsa.e );
 	if( skc->is_protected ) {
@@ -314,6 +321,37 @@ do_secret_cert( IOBUF out, int ctb, PKT_secret_cert *skc )
     return rc;
 }
 
+static int
+do_symkey_enc( IOBUF out, int ctb, PKT_symkey_enc *enc )
+{
+    int rc = 0;
+    IOBUF a = iobuf_temp();
+
+    assert( enc->version == 4 );
+    switch( enc->s2k.mode ) {
+      case 0: case 1: case 4: break;
+      default: log_bug("do_symkey_enc: s2k=%d\n", enc->s2k.mode );
+    }
+    iobuf_put( a, enc->version );
+    iobuf_put( a, enc->cipher_algo );
+    iobuf_put( a, enc->s2k.mode );
+    iobuf_put( a, enc->s2k.hash_algo );
+    if( enc->s2k.mode == 1 || enc->s2k.mode == 4 ) {
+	iobuf_write(a, enc->s2k.salt, 8 );
+	if( enc->s2k.mode == 4 )
+	    write_32(a, enc->s2k.count);
+    }
+    if( enc->seskeylen )
+	iobuf_write(a, enc->seskey, enc->seskeylen );
+
+    write_header(out, ctb, iobuf_get_temp_length(a) );
+    if( iobuf_write_temp( out, a ) )
+	rc = G10ERR_WRITE_FILE;
+
+    iobuf_close(a);
+    return rc;
+}
+
 static int
 do_pubkey_enc( IOBUF out, int ctb, PKT_pubkey_enc *enc )
 {
@@ -324,11 +362,11 @@ do_pubkey_enc( IOBUF out, int ctb, PKT_pubkey_enc *enc )
     write_32(a, enc->keyid[0] );
     write_32(a, enc->keyid[1] );
     iobuf_put(a,enc->pubkey_algo );
-    if( enc->pubkey_algo == PUBKEY_ALGO_ELGAMAL ) {
+    if( is_ELGAMAL(enc->pubkey_algo) ) {
 	mpi_write(a, enc->d.elg.a );
 	mpi_write(a, enc->d.elg.b );
     }
-    else if( enc->pubkey_algo == PUBKEY_ALGO_RSA ) {
+    else if( is_RSA(enc->pubkey_algo) ) {
 	mpi_write(a, enc->d.rsa.rsa_integer );
     }
     else {
@@ -348,7 +386,6 @@ do_pubkey_enc( IOBUF out, int ctb, PKT_pubkey_enc *enc )
 
 
 
-
 static u32
 calc_plaintext( PKT_plaintext *pt )
 {
@@ -358,8 +395,10 @@ calc_plaintext( PKT_plaintext *pt )
 static int
 do_plaintext( IOBUF out, int ctb, PKT_plaintext *pt )
 {
-    int c, i, rc = 0;
+    int i, rc = 0;
     u32 n;
+    byte buf[1000]; /* FIXME: this buffer has the plaintext! */
+    int nbytes;
 
     write_header(out, ctb, calc_plaintext( pt ) );
     iobuf_put(out, pt->mode );
@@ -370,13 +409,14 @@ do_plaintext( IOBUF out, int ctb, PKT_plaintext *pt )
 	rc = G10ERR_WRITE_FILE;
 
     n = 0;
-    while( (c=iobuf_get(pt->buf)) != -1 ) {
-	if( iobuf_put(out, c) ) {
+    while( (nbytes=iobuf_read(pt->buf, buf, 1000)) != -1 ) {
+	if( iobuf_write(out, buf, nbytes) == -1 ) {
 	    rc = G10ERR_WRITE_FILE;
 	    break;
 	}
-	n++;
+	n += nbytes;
     }
+    memset(buf,0,1000); /* at least burn the buffer */
     if( !pt->len )
 	iobuf_set_block_mode(out, 0 ); /* write end marker */
     else if( n != pt->len )
@@ -443,7 +483,7 @@ do_signature( IOBUF out, int ctb, PKT_signature *sig )
     }
     iobuf_put(a, sig->digest_start[0] );
     iobuf_put(a, sig->digest_start[1] );
-    if( sig->pubkey_algo == PUBKEY_ALGO_ELGAMAL ) {
+    if( is_ELGAMAL(sig->pubkey_algo) ) {
 	mpi_write(a, sig->d.elg.a );
 	mpi_write(a, sig->d.elg.b );
     }
@@ -451,7 +491,7 @@ do_signature( IOBUF out, int ctb, PKT_signature *sig )
 	mpi_write(a, sig->d.dsa.r );
 	mpi_write(a, sig->d.dsa.s );
     }
-    else if( sig->pubkey_algo == PUBKEY_ALGO_RSA ) {
+    else if( is_RSA(sig->pubkey_algo) ) {
 	mpi_write(a, sig->d.rsa.rsa_integer );
     }
     else {
