@@ -116,8 +116,12 @@ static ARGPARSE_OPTS opts[] = {
     { 536, "marginals-needed", 1, N_("(default is 3)")},
   #ifdef IS_G10
     { 527, "cipher-algo", 2 , N_("select default cipher algorithm")},
-    { 528, "pubkey-algo", 2 , N_("select default puplic key algorithm")},
+    { 528, "pubkey-algo", 2 , N_("select default public key algorithm")},
     { 529, "digest-algo", 2 , N_("select default message digest algorithm")},
+  #else /* some dummies */
+    { 527, "cipher-algo", 2 , "\r"},
+    { 528, "pubkey-algo", 2 , "\r"},
+    { 529, "digest-algo", 2 , "\r"},
   #endif
 
   #ifdef IS_G10
@@ -156,7 +160,7 @@ static ARGPARSE_OPTS opts[] = {
     { 551, "list-key", 0, "\r" }, /* alias */
     { 552, "list-sig", 0, "\r" }, /* alias */
     { 508, "check-sig",0, "\r" }, /* alias */
-
+    { 553, "skip-verify",0, "\r" },
 
 {0} };
 
@@ -254,11 +258,11 @@ build_list( const char *text, const char * (*mapf)(int), int (*chkf)(int) )
     size_t n=strlen(text)+2;
     char *list, *p;
 
-    for(i=1; i < 100; i++ )
+    for(i=1; i < 110; i++ )
 	if( !chkf(i) && (s=mapf(i)) )
 	    n += strlen(s) + 2;
     list = m_alloc( 21 + n ); *list = 0;
-    for(p=NULL, i=1; i < 100; i++ ) {
+    for(p=NULL, i=1; i < 110; i++ ) {
 	if( !chkf(i) && (s=mapf(i)) ) {
 	    if( !p )
 		p = stpcpy( list, text );
@@ -412,7 +416,7 @@ main( int argc, char **argv )
       #endif
     }
 
-    /* check wether we have a config file on the commandline */
+    /* check whether we have a config file on the commandline */
     orig_argc = argc;
     orig_argv = argv;
     pargs.argc = &argc;
@@ -509,7 +513,12 @@ main( int argc, char **argv )
 	  case 540: secmem_set_flags( secmem_get_flags() | 1 ); break;
 	  case 542: set_cmd( &cmd, aGenRevoke); break;
 	  case 550: set_cmd( &cmd, aVerify); break;
-	#endif /* IS_G10 */
+	#else
+	  case 527:
+	  case 528:
+	  case 529:
+	    break;
+	#endif /* !IS_G10 */
 
 	#ifdef IS_G10MAINT
 	  case 513: set_cmd( &cmd, aPrimegen); break;
@@ -564,6 +573,7 @@ main( int argc, char **argv )
 	  case 549: opt.with_colons=':'; break;
 	  case 551: set_cmd( &cmd, aListKeys); break;
 	  case 552: set_cmd( &cmd, aListSigs); break;
+	  case 553: opt.skip_verify=1; break;
 	  default : errors++; pargs.err = configfp? 1:2; break;
 	}
     }
@@ -632,9 +642,9 @@ main( int argc, char **argv )
     else {
 	fname = NULL;
 	if( get_passphrase_fd() == 0 ) {
-	    /* reading data and passphrase form stdin:
+	    /* reading data and passphrase from stdin:
 	     * we assume the first line is the passphrase, so
-	     * we better should read it now.
+	     * we should read it now.
 	     *
 	     * We should do it here, but for now it is not needed.
 	     * Anyway, this password scheme is not quite good
@@ -804,7 +814,7 @@ main( int argc, char **argv )
     #ifdef IS_G10
       case aKeygen: /* generate a key (interactive) */
 	if( argc )
-	    wrong_args(_("--gen-key"));
+	    wrong_args("--gen-key");
 	generate_keypair();
 	break;
     #endif
@@ -932,7 +942,7 @@ main( int argc, char **argv )
       case aListPackets:
 	opt.list_packets=1;
       default:
-	/* fixme: g10maint should to regular maintenace tasks here */
+	/* fixme: g10maint should do regular maintenace tasks here */
 	if( argc > 1 )
 	    wrong_args(_("[filename]"));
 	if( !(a = iobuf_open(fname)) )
@@ -985,6 +995,13 @@ print_hex( byte *p, size_t n )
 	    printf(" %02X%02X", *p, p[1] );
 	}
     }
+    else if( n == 24 ) {
+	for(i=0; i < n ; i += 4, p += 4 ) {
+	    if( i == 12 )
+		putchar(' ');
+	    printf(" %02X%02X%02X%02X", *p, p[1], p[2], p[3] );
+	}
+    }
     else {
 	for(i=0; i < n ; i++, p++ ) {
 	    if( i && !(i%8) )
@@ -1014,8 +1031,11 @@ print_mds( const char *fname )
     }
 
     md = md_open( DIGEST_ALGO_MD5, 0 );
-    md_enable( md, DIGEST_ALGO_RMD160 );
     md_enable( md, DIGEST_ALGO_SHA1 );
+    md_enable( md, DIGEST_ALGO_RMD160 );
+  #ifdef WITH_TIGER_HASH
+    md_enable( md, DIGEST_ALGO_TIGER );
+  #endif
 
     while( (n=fread( buf, 1, DIM(buf), fp )) )
 	md_write( md, buf, n );
@@ -1024,8 +1044,11 @@ print_mds( const char *fname )
     else {
 	md_final(md);
 	printf(  "%s:    MD5 =", fname ); print_hex(md_read(md, DIGEST_ALGO_MD5), 16 );
-	printf("\n%s: RMD160 =", fname ); print_hex(md_read(md, DIGEST_ALGO_RMD160), 20 );
 	printf("\n%s:   SHA1 =", fname ); print_hex(md_read(md, DIGEST_ALGO_SHA1), 20 );
+	printf("\n%s: RMD160 =", fname ); print_hex(md_read(md, DIGEST_ALGO_RMD160), 20 );
+      #ifdef WITH_TIGER_HASH
+	printf("\n%s:  TIGER =", fname ); print_hex(md_read(md, DIGEST_ALGO_TIGER), 24 );
+      #endif
 	putchar('\n');
     }
 
