@@ -50,7 +50,7 @@ typedef struct {
     int encrypt_only; /* process only encrytion messages */
     STRLIST signed_data;
     DEK *dek;
-    int last_was_pubkey_enc;
+    int last_was_session_key;
     KBNODE list;   /* the current list of packets */
     int have_data;
     IOBUF iobuf;    /* used to get the filename etc. */
@@ -145,18 +145,33 @@ add_signature( CTX c, PACKET *pkt )
 }
 
 
+static void
+proc_symkey_enc( CTX c, PACKET *pkt )
+{
+    PKT_symkey_enc *enc;
+
+    enc = pkt->pkt.symkey_enc;
+    if( enc->seskeylen )
+	log_error( "symkey_enc packet with session keys are not supported!\n");
+    else {
+	c->last_was_session_key = 2;
+	c->dek = passphrase_to_dek( NULL, enc->cipher_algo, &enc->s2k, 0 );
+    }
+    free_packet(pkt);
+}
+
 static void
 proc_pubkey_enc( CTX c, PACKET *pkt )
 {
     PKT_pubkey_enc *enc;
     int result = 0;
 
-    c->last_was_pubkey_enc = 1;
+    c->last_was_session_key = 1;
     enc = pkt->pkt.pubkey_enc;
     /*printf("enc: encrypted by a pubkey with keyid %08lX\n", enc->keyid[1] );*/
-    if( enc->pubkey_algo == PUBKEY_ALGO_ELGAMAL
+    if( is_ELGAMAL(enc->pubkey_algo)
 	|| enc->pubkey_algo == PUBKEY_ALGO_DSA
-	|| enc->pubkey_algo == PUBKEY_ALGO_RSA	) {
+	|| is_RSA(enc->pubkey_algo)  ) {
 	m_free(c->dek ); /* paranoid: delete a pending DEK */
 	c->dek = m_alloc_secure( sizeof *c->dek );
 	if( (result = get_session_key( enc, c->dek )) ) {
@@ -179,18 +194,15 @@ proc_pubkey_enc( CTX c, PACKET *pkt )
 }
 
 
-
 static void
 proc_encrypted( CTX c, PACKET *pkt )
 {
     int result = 0;
 
     /*printf("dat: %sencrypted data\n", c->dek?"":"conventional ");*/
-    if( !c->dek && !c->last_was_pubkey_enc ) {
-	/* assume this is conventional encrypted data */
-	c->dek = m_alloc_secure( sizeof *c->dek );
-	c->dek->algo = opt.def_cipher_algo;
-	result = make_dek_from_passphrase( c->dek, 0, NULL );
+    if( !c->dek && !c->last_was_session_key ) {
+	/* assume this is old conventional encrypted data */
+	c->dek = passphrase_to_dek( NULL, opt.def_cipher_algo, NULL, 0 );
     }
     else if( !c->dek )
 	result = G10ERR_NO_SECKEY;
@@ -207,7 +219,7 @@ proc_encrypted( CTX c, PACKET *pkt )
 	log_error("encryption failed: %s\n", g10_errstr(result));
     }
     free_packet(pkt);
-    c->last_was_pubkey_enc = 0;
+    c->last_was_session_key = 0;
 }
 
 
@@ -220,7 +232,7 @@ proc_plaintext( CTX c, PACKET *pkt )
     if( opt.verbose )
 	log_info("original file name='%.*s'\n", pt->namelen, pt->name);
     free_md_filter_context( &c->mfx );
-    /* fixme: take the digest algo(s) to use from the
+    /* FIXME: take the digest algo(s) to use from the
      * onepass_sig packet (if we have these)
      * And look at the sigclass to check whether we should use the
      * textmode filter (sigclass 0x01)
@@ -228,11 +240,12 @@ proc_plaintext( CTX c, PACKET *pkt )
     c->mfx.md = md_open( DIGEST_ALGO_RMD160, 0);
     md_enable( c->mfx.md, DIGEST_ALGO_SHA1 );
     md_enable( c->mfx.md, DIGEST_ALGO_MD5 );
+    md_enable( c->mfx.md, DIGEST_ALGO_TIGER );
     rc = handle_plaintext( pt, &c->mfx );
     if( rc )
 	log_error( "handle plaintext failed: %s\n", g10_errstr(rc));
     free_packet(pkt);
-    c->last_was_pubkey_enc = 0;
+    c->last_was_session_key = 0;
 }
 
 
@@ -264,7 +277,7 @@ proc_compressed( CTX c, PACKET *pkt )
     if( rc )
 	log_error("uncompressing failed: %s\n", g10_errstr(rc));
     free_packet(pkt);
-    c->last_was_pubkey_enc = 0;
+    c->last_was_session_key = 0;
 }
 
 
@@ -284,7 +297,7 @@ do_check_sig( CTX c, KBNODE node )
     assert( node->pkt->pkttype == PKT_SIGNATURE );
     sig = node->pkt->pkt.signature;
 
-    algo = digest_algo_from_sig( sig );
+    algo = sig->digest_algo;
     if( !algo )
 	return G10ERR_PUBKEY_ALGO;
     if( (rc=check_digest_algo(algo)) )
@@ -606,6 +619,7 @@ do_proc_packets( CTX c, IOBUF a )
 	      case PKT_PUBLIC_CERT:
 	      case PKT_SECRET_CERT:
 	      case PKT_USER_ID:
+	      case PKT_SYMKEY_ENC:
 	      case PKT_PUBKEY_ENC:
 	      case PKT_ENCRYPTED:
 		rc = G10ERR_UNEXPECTED;
@@ -625,6 +639,7 @@ do_proc_packets( CTX c, IOBUF a )
 		rc = G10ERR_UNEXPECTED;
 		goto leave;
 	      case PKT_SIGNATURE:   newpkt = add_signature( c, pkt ); break;
+	      case PKT_SYMKEY_ENC:  proc_symkey_enc( c, pkt ); break;
 	      case PKT_PUBKEY_ENC:  proc_pubkey_enc( c, pkt ); break;
 	      case PKT_ENCRYPTED:   proc_encrypted( c, pkt ); break;
 	      case PKT_PLAINTEXT:   proc_plaintext( c, pkt ); break;
@@ -648,6 +663,7 @@ do_proc_packets( CTX c, IOBUF a )
 	      case PKT_USER_ID:     newpkt = add_user_id( c, pkt ); break;
 	      case PKT_SIGNATURE:   newpkt = add_signature( c, pkt ); break;
 	      case PKT_PUBKEY_ENC:  proc_pubkey_enc( c, pkt ); break;
+	      case PKT_SYMKEY_ENC:  proc_symkey_enc( c, pkt ); break;
 	      case PKT_ENCRYPTED:   proc_encrypted( c, pkt ); break;
 	      case PKT_PLAINTEXT:   proc_plaintext( c, pkt ); break;
 	      case PKT_COMPRESSED:  proc_compressed( c, pkt ); break;
@@ -753,8 +769,7 @@ proc_tree( CTX c, KBNODE node )
 	    c->mfx.md = md_open(0, 0);
 	    /* fixme: why looking for the signature packet and not 1passpacket*/
 	    for( n1 = node; (n1 = find_next_kbnode(n1, PKT_SIGNATURE )); ) {
-		md_enable( c->mfx.md,
-			   digest_algo_from_sig(n1->pkt->pkt.signature));
+		md_enable( c->mfx.md, n1->pkt->pkt.signature->digest_algo);
 	    }
 	    /* ask for file and hash it */
 	    if( c->sigs_only )
@@ -777,7 +792,7 @@ proc_tree( CTX c, KBNODE node )
 
 	if( !c->have_data ) {
 	    free_md_filter_context( &c->mfx );
-	    c->mfx.md = md_open(digest_algo_from_sig(sig), 0);
+	    c->mfx.md = md_open(sig->digest_algo, 0);
 	    if( c->sigs_only )
 		rc = hash_datafiles( c->mfx.md, c->signed_data,
 				     sig->sig_class == 0x01 );
