@@ -33,7 +33,7 @@
 
 static int pwfd = -1;
 
-static int hash_passphrase( DEK *dek, char *pw, byte *salt );
+static void hash_passphrase( DEK *dek, char *pw, STRING2KEY *s2k, int create );
 
 void
 set_passphrase_fd( int fd )
@@ -51,13 +51,29 @@ get_passphrase_fd()
 /****************
  * Get a passphrase for the secret key with KEYID, display TEXT
  * if the user needs to enter the passphrase.
- * Returns: m_alloced md5 passphrase hash; caller must free
+ * mode 0 = standard, 2 = create new passphrase
+ * Returns: a DEK with a session key; caller must free
+ *	    or NULL if the passphrase was not correctly repeated.
+ *	    (only for mode 2)
+ *	    a dek->keylen of 0 means: no passphrase entered.
+ *	    (only for mode 2)
  */
 DEK *
-get_passphrase_hash( u32 *keyid, char *text, byte *salt )
+passphrase_to_dek( u32 *keyid, int cipher_algo, STRING2KEY *s2k, int mode )
 {
     char *pw;
     DEK *dek;
+    STRING2KEY help_s2k;
+
+    if( !s2k ) {
+	s2k = &help_s2k;
+	s2k->mode = 0;
+	/* this should be MD5 if cipher is IDEA, but because we do
+	 * not have IDEA, we use the default one, the the user
+	 * can select it from the commandline
+	 */
+	s2k->hash_algo = opt.def_digest_algo;
+    }
 
     if( keyid && !opt.batch ) {
 	char *ustr;
@@ -95,82 +111,51 @@ get_passphrase_hash( u32 *keyid, char *text, byte *salt )
     else {
 	pw = tty_get_hidden("Enter pass phrase: " );
 	tty_kill_prompt();
+	if( mode == 2 ) {
+	    char *pw2 = tty_get_hidden("Repeat pass phrase: " );
+	    tty_kill_prompt();
+	    if( strcmp(pw, pw2) ) {
+		m_free(pw2);
+		m_free(pw);
+		return NULL;
+	    }
+	    m_free(pw2);
+	}
     }
     dek = m_alloc_secure( sizeof *dek );
-    dek->algo = CIPHER_ALGO_BLOWFISH; /* fixme: allow others ciphers */
-    if( hash_passphrase( dek, pw, salt ) )
-	log_bug("get_passphrase_hash\n");
+    dek->algo = cipher_algo;
+    if( !*pw && mode == 2 )
+	dek->keylen = 0;
+    else
+	hash_passphrase( dek, pw, s2k, mode==2 );
     m_free(pw); /* is allocated in secure memory, so it will be burned */
     return dek;
 }
 
 
 /****************
- * This function is used to construct a DEK from a user input.
- * It uses the default CIPHER. If salt is != NULL, include these
- * 8 bytes in the hash.
- * Returns: 0 = okay, -1 No passphrase entered, > 0 error
+ * Hash a passphrase using the supplied s2k. If create is true, create
+ * a new salt or whatelse must be filled into the s2k for a new key.
+ * always needs: dek->algo, s2k->mode, s2k->hash_algo.
  */
-int
-make_dek_from_passphrase( DEK *dek, int mode, byte *salt )
+static void
+hash_passphrase( DEK *dek, char *pw, STRING2KEY *s2k, int create )
 {
-    char *pw, *pw2;
-    int rc=0;
-
-    pw = tty_get_hidden("Enter pass phrase: " );
-    tty_kill_prompt();
-    if( mode == 2 ) {
-	pw2 = tty_get_hidden("Repeat pass phrase: " );
-	tty_kill_prompt();
-	if( strcmp(pw, pw2) ) {
-	    m_free(pw2);
-	    m_free(pw);
-	    return G10ERR_PASSPHRASE;
-	}
-	m_free(pw2);
-    }
-    if( !*pw )
-	rc = -1;
-    else
-	rc = hash_passphrase( dek, pw, salt );
-    m_free(pw);
-    return rc;
-}
-
-
-static int
-hash_passphrase( DEK *dek, char *pw, byte *salt )
-{
-    int rc = 0;
+    MD_HANDLE md;
 
+    assert( s2k->hash_algo );
     dek->keylen = 0;
-    if( dek->algo == CIPHER_ALGO_BLOWFISH ) {
-	MD_HANDLE md;
-
-	md = md_open(DIGEST_ALGO_RMD160, 1);
-	if( salt )
-	    md_write( md, salt, 8 );
-	md_write( md, pw, strlen(pw) );
-	md_final( md );
-	dek->keylen = 20;
-	memcpy( dek->key, md_read(md,0), dek->keylen );
-	md_close(md);
+    md = md_open( s2k->hash_algo, 1);
+    if( s2k->mode == 1 || s2k->mode == 4 ) {
+	if( create )
+	    randomize_buffer(s2k->salt, 8, 1);
+	md_write( md, s2k->salt, 8 );
     }
-    else if( dek->algo == CIPHER_ALGO_CAST ) {
-	MD_HANDLE md;
-
-	md = md_open(DIGEST_ALGO_SHA1, 1);
-	if( salt )
-	    md_write( md, salt, 8 );
-	md_write( md, pw, strlen(pw) );
-	md_final( md );
-	/* use only the low 128 bits */
-	dek->keylen = 16;
-	memcpy( dek->key, md_read(md,0), dek->keylen );
-	md_close(md);
-    }
-    else
-	rc = G10ERR_UNSUPPORTED;
-    return rc;
+    md_write( md, pw, strlen(pw) );
+    md_final( md );
+    dek->keylen = cipher_get_keylen( dek->algo ) / 8;
+    assert(dek->keylen > 0 && dek->keylen <= DIM(dek->key) );
+    memcpy( dek->key, md_read(md,0), dek->keylen );
+    md_close(md);
 }
 
